@@ -33,3 +33,7 @@ CLI_OPTIMIZATION_TARGET = 'optimization_target'
 CLI_OPTIMIZATION_NONE = 'none'
 CLI_OPTIMIZATION_CPU = 'cpu'
 CLI_OPTIMIZATION_GPU = 'gpu'
+CLI_OUTPUTS = 'outputs'
+CLI_SIGNATURE_KEY = 'signature_key'
+CLI_METHOD_NAME = 'method_name'
+CLI_RENAME = 'rename'
